import { JSXInterface } from '../jsx';
import { CSSResultGroup, PropertyValues, TemplateResult } from '@refinitiv-ui/core';
import { Collapse } from '../collapse/index.js';
/**
 * Used to display a group of `Collapse` control.
 * Only one item will be able to expand by default but you can customize its behavior.
 *
 * @slot header-left - Slot to add custom contents to the left side of header
 * @slot header-right - Slot to add custom contents to the right side of header
 *
 */
export declare class Accordion extends Collapse {
    /**
     * Element version number
     * @returns version number
     */
    static get version(): string;
    /**
     * A `CSSResultGroup` that will be used
     * to style the host, slotted children
     * and the internal template of the element.
     * @return CSS template
     */
    static get styles(): CSSResultGroup;
    /**
     * Allow multiple sections expand at the same time
     */
    autoCollapseDisabled: boolean;
    /**
     * Add spacing to content section in all collapse items
     */
    spacing: boolean;
    /**
     * Called once after the component is first rendered
     * @param changedProperties map of changed properties with old values
     * @returns {void}
     */
    protected firstUpdated(changedProperties: PropertyValues): void;
    /**
     * handle bubbled clicks from items
     * @param event the click event object
     * @return void
     */
    private handleClick;
    /**
     * get a list of items
     * @returns array of accordion items
     */
    private getChildItems;
    /**
     * collapse non selected child items on click
     * @param target currently selected item
     * @return void
     */
    private processChildrenOnClick;
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     * @return {TemplateResult}  Render template
     */
    protected render(): TemplateResult;
}
declare global {
    interface HTMLElementTagNameMap {
        'ef-accordion': Accordion;
    }
}

declare global {
  interface HTMLElementTagNameMap {
    'ef-accordion': Accordion;
  }

  namespace JSX {
    interface IntrinsicElements {
      'ef-accordion': Partial<Accordion> | JSXInterface.HTMLAttributes<Accordion>;
    }
  }
}

export {};
