import { JSXInterface } from '../jsx';
import { BasicElement, CSSResultGroup, TemplateResult } from '@refinitiv-ui/core';
import '@refinitiv-ui/phrasebook/locale/en/appstate-bar.js';
import { Translate } from '@refinitiv-ui/translate';
import '../icon/index.js';
/**
 * Used to display at the top of application to provide a status or information.
 * @slot right - Place custom content on the right of bar.
 *
 * @fires clear - Fired when the user taps clear button.
 */
export declare class AppstateBar extends BasicElement {
    /**
     * Element version number
     * @returns version number
     */
    static get version(): string;
    /**
     * A `CSSResultGroup` that will be used
     * to style the host, slotted children
     * and the internal template of the element.
     *
     * @returns CSS template
     */
    static get styles(): CSSResultGroup;
    /**
     * Text to display in heading section.
     */
    heading: string;
    /**
     * Type of state bar.
     */
    state: 'info' | 'highlight' | null;
    /**
     * Used for translations
     */
    protected t: Translate;
    /**
     * Hide the element when clear button is clicked
     * @param {Event} event - event params
     * @fires AppstateBar#clear
     * @returns {void}
     */
    private clear;
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     * @return {TemplateResult}  Render template
     */
    protected render(): TemplateResult;
}
declare global {
    interface HTMLElementTagNameMap {
        'ef-appstate-bar': AppstateBar;
    }
}

declare global {
  interface HTMLElementTagNameMap {
    'ef-appstate-bar': AppstateBar;
  }

  namespace JSX {
    interface IntrinsicElements {
      'ef-appstate-bar': Partial<AppstateBar> | JSXInterface.HTMLAttributes<AppstateBar>;
    }
  }
}

export {};
