import { __decorate } from "tslib";
import { BasicElement, css, html } from '@refinitiv-ui/core';
import { customElement } from '@refinitiv-ui/core/decorators/custom-element.js';
import { property } from '@refinitiv-ui/core/decorators/property.js';
import '@refinitiv-ui/phrasebook/locale/en/appstate-bar.js';
import { translate } from '@refinitiv-ui/translate';
import '../icon/index.js';
import { VERSION } from '../version.js';
/**
 * Used to display at the top of application to provide a status or information.
 * @slot right - Place custom content on the right of bar.
 *
 * @fires clear - Fired when the user taps clear button.
 */
let AppstateBar = class AppstateBar extends BasicElement {
    constructor() {
        super(...arguments);
        /**
         * Text to display in heading section.
         */
        this.heading = '';
        /**
         * Type of state bar.
         */
        this.state = null;
        /**
         * Hide the element when clear button is clicked
         * @param {Event} event - event params
         * @fires AppstateBar#clear
         * @returns {void}
         */
        this.clear = (event) => {
            event.stopPropagation();
            this.style.display = 'none';
            this.dispatchEvent(new CustomEvent('clear'));
        };
    }
    /**
     * Element version number
     * @returns version number
     */
    static get version() {
        return VERSION;
    }
    /**
     * A `CSSResultGroup` that will be used
     * to style the host, slotted children
     * and the internal template of the element.
     *
     * @returns CSS template
     */
    static get styles() {
        return css `
      :host {
        display: block;
      }
    `;
    }
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     * @return {TemplateResult}  Render template
     */
    render() {
        return html `
      <div part="heading">${this.heading}</div>
      <div part="message"><slot></slot></div>
      <div part="right"><slot name="right"></slot></div>
      <ef-icon
        role="button"
        part="close"
        @tap="${this.clear}"
        icon="cross"
        aria-label="${this.t('CLOSE')}"
      ></ef-icon>
    `;
    }
};
__decorate([
    property({ type: String })
], AppstateBar.prototype, "heading", void 0);
__decorate([
    property({ type: String, reflect: true })
], AppstateBar.prototype, "state", void 0);
__decorate([
    translate()
], AppstateBar.prototype, "t", void 0);
AppstateBar = __decorate([
    customElement('ef-appstate-bar')
], AppstateBar);
export { AppstateBar };
