import { TranslateParams } from '@refinitiv-ui/i18n';
import { CalendarCell, Cell } from './types.js';
export type MonthInfo = {
    days: number;
    month: number;
    year: number;
};
/**
 * Get information about number of days, month number and year from date object
 * @param value Date string
 * @returns Month information object
 */
declare const monthInfo: (value: string) => MonthInfo;
/**
 * Get a list of weekday abbreviations based on locale
 * @param locale Locale
 * @param [width='short'] Day width
 * @returns The list of weekdays starting from Sunday
 */
declare const weekdaysNames: (locale: string, width?: Intl.DateTimeFormatOptions['weekday']) => string[];
/**
 * Get a list of months based on locale
 * @param locale Locale
 * @param [width='short'] Month width
 * @returns The list of months starting from January
 */
declare const monthsNames: (locale: string, width?: Intl.DateTimeFormatOptions['month']) => string[];
/**
 * Used to format views
 */
declare const ViewFormatTranslateParams: TranslateParams;
/**
 * convert internal Cell to CalendarCell
 * avoid introducing breaking changes to the API
 * @param cell Cell
 * @returns CalendarCell
 */
declare const toCalendarCell: (cell: Cell) => CalendarCell;
export { monthInfo, weekdaysNames, monthsNames, toCalendarCell, ViewFormatTranslateParams };
