import { __decorate } from "tslib";
import { css, html, svg } from '@refinitiv-ui/core';
import { customElement } from '@refinitiv-ui/core/decorators/custom-element.js';
import { VERSION } from '../../version.js';
import { COLOR_ITEMS } from '../helpers/color-helpers.js';
import { Palettes } from './palettes.js';
/**
 * Component that allows user to select
 * any colours by tapping or dragging
 */
let ColorPalettes = class ColorPalettes extends Palettes {
    /**
     * Element version number
     * @returns version number
     */
    static get version() {
        return VERSION;
    }
    /**
     * A `CSSResultGroup` that will be used
     * to style the host, slotted children
     * and the internal template of the element.
     * @return CSS template
     */
    static get styles() {
        return css `
      :host {
        display: block;
      }
      svg {
        width: 100%;
      }
      .color-selector {
        stroke: #fff;
        stroke-width: 2;
        fill: none;
        pointer-events: none;
      }
      .color-selector-shadow {
        stroke: black;
        stroke-width: 3;
        fill: none;
        pointer-events: none;
      }
    `;
    }
    /**
     * create color items template from COLOR_ITEMS array
     * @return color items template
     */
    get ColorItemsTemplate() {
        return COLOR_ITEMS.map((item) => {
            return svg `
          <polygon
            data-role="color-item"
            stroke=${item[1]}
            fill=${item[1]}
            points=${item[0]}
            @tap=${this.onTapItem}
            @mousemove=${this.onMousemove}
            @touchmove=${this.onTouchmove}
          >
          </polygon>
        `;
        });
    }
    /**
     * Update color selector element when value has been changed
     * @param changedProperties Properties that has changed
     * @return {void}
     */
    updated(changedProperties) {
        if (changedProperties.has('value')) {
            const value = this.expandHex(this.value);
            const item = COLOR_ITEMS.find((item) => item[1] === value);
            if (item) {
                this.showSelector(item[0]);
            }
            else {
                this.hideSelector();
            }
        }
    }
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     * @return {TemplateResult}  Render template
     */
    render() {
        return html `
      <svg id="colorPalettes" viewBox="-5 -5 245 210">
        ${this.ColorItemsTemplate} ${this.SelectorTemplate}
      </svg>
    `;
    }
};
ColorPalettes = __decorate([
    customElement('ef-color-palettes', { theme: false })
], ColorPalettes);
export { ColorPalettes };
