import escapeStringRegexp from 'escape-string-regexp';
import { CollectionComposer } from '@refinitiv-ui/utils/collection.js';
/**
 * Default filter used by combo box
 * @param el ComboBox instance to filter
 * @returns Filter accepting an item
 */
export const createDefaultFilter = (el) => {
    // reference query string for validating queryRegExp cache state
    let query = '';
    // cache RegExp
    let queryRegExp;
    // Get current RegExp, or renew if out of date
    // this is fetched on demand by filter/renderer
    // only created once per query
    const getRegularExpressionOfQuery = () => {
        if (el.query !== query || !queryRegExp) {
            query = el.query ?? '';
            queryRegExp = new RegExp(escapeStringRegexp(query), 'i');
        }
        return queryRegExp;
    };
    // return scoped custom filter
    return (item, context) => {
        let label;
        if (context) {
            const composer = context instanceof CollectionComposer ? context : context.composer;
            label = composer.getItemPropertyValue(item, 'label');
        }
        else {
            label = item.label;
        }
        const regex = getRegularExpressionOfQuery();
        const result = regex.test(label);
        return result;
    };
};
