import { __decorate } from "tslib";
import { BasicElement, css, html } from '@refinitiv-ui/core';
import { customElement } from '@refinitiv-ui/core/decorators/custom-element.js';
import { property } from '@refinitiv-ui/core/decorators/property.js';
import { VERSION } from '../version.js';
/**
 * Use to identify and separate different sections of a page.
 * Headers helps to organize the page layout content into
 * a sensible hierarchy and improve the user experience.
 *
 * @slot left - Slot to add custom contents to the left side of header
 * @slot right - Slot to add custom contents to the right side of header
 */
let Header = class Header extends BasicElement {
    constructor() {
        super(...arguments);
        /**
         * Use level styling from theme
         */
        this.level = '2';
    }
    /**
     * Element version number
     * @returns version number
     */
    static get version() {
        return VERSION;
    }
    /**
     * Style definition
     * @return CSS template
     */
    static get styles() {
        return css `
      :host {
        display: block;
      }
      :host ::slotted(*) {
        margin-top: 0;
        margin-bottom: 0;
        vertical-align: middle;
      }
      [part='label'] {
        text-align: inherit;
      }
    `;
    }
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     * @return Render template
     */
    render() {
        return html `
      <slot name="left">
        <div part="spacer"></div>
      </slot>
      <div part="label">
        <slot></slot>
      </div>
      <slot name="right"></slot>
    `;
    }
};
__decorate([
    property({ type: String, reflect: true })
], Header.prototype, "level", void 0);
Header = __decorate([
    customElement('ef-header')
], Header);
export { Header };
