import { DeprecationNotice } from '@refinitiv-ui/core';
import { uuid } from '@refinitiv-ui/utils/uuid.js';
import { Renderer } from '../renderer.js';
import { getItemId } from './item-id.js';
export const createListRenderer = (context) => {
    /**
     * Renderer key prefix, used in combination with item value to give unique id to each item
     */
    const key = uuid();
    return (item, composer, element) => {
        /**
         * Element to render
         */
        const el = element || document.createElement('ef-list-item');
        /**
         * Tooltip value to be used, if any.
         */
        const tooltip = composer.getItemPropertyValue(item, 'tooltip');
        el.label = composer.getItemPropertyValue(item, 'label');
        el.subLabel = composer.getItemPropertyValue(item, 'subLabel');
        el.value = composer.getItemPropertyValue(item, 'value');
        el.id = getItemId(key, el.value);
        el.icon = composer.getItemPropertyValue(item, 'icon');
        el.highlighted = composer.getItemPropertyValue(item, 'highlighted') === true;
        el.selected = composer.getItemPropertyValue(item, 'selected') === true;
        el.disabled = composer.getItemPropertyValue(item, 'disabled') === true;
        el.hidden = composer.getItemPropertyValue(item, 'hidden') === true;
        el.type = composer.getItemPropertyValue(item, 'type');
        el.multiple = !!context && context.multiple === true;
        const itemRole = el.type === 'text' || !el.type ? 'option' : 'presentation';
        el.setAttribute('role', itemRole);
        tooltip ? el.setAttribute('title', tooltip) : el.removeAttribute('title');
        return el;
    };
};
const deprecationNotice = new DeprecationNotice('ListRenderer is deprecated. Use createListRenderer instead.');
/**
 * Renders list items as `ef-item` elements.
 * This is the default renderer for lists.
 * @deprecate ListRenderer is deprecated. Use createListRenderer instead.
 */
export class ListRenderer extends Renderer {
    constructor(context) {
        /**
         * Create and return render function
         */
        super(createListRenderer(context));
        deprecationNotice.show();
    }
}
