import { __decorate } from "tslib";
import { BasicElement, html } from '@refinitiv-ui/core';
import { customElement } from '@refinitiv-ui/core/decorators/custom-element.js';
import { VERSION } from '../version.js';
/**
 * Global cache for loader template parts
 */
let cachedParts;
/**
 *  An animated graphical component,
 *  used to show that an app is performing an action
 *  in the background such as downloading content.
 */
let Loader = class Loader extends BasicElement {
    constructor() {
        super(...arguments);
        this.defaultRole = 'progressbar';
    }
    /**
     * Element version number
     * @returns version number
     */
    static get version() {
        return VERSION;
    }
    /**
     * Collection of template part names,
     * used to create and theme different loader styles
     */
    get templateParts() {
        const parts = cachedParts ||
            this.getComputedVariable('--parts')
                .split(',')
                .map((part) => part.trim())
                .filter((part) => part);
        if (cachedParts !== parts && parts.length) {
            cachedParts = parts;
        }
        return parts;
    }
    firstUpdated(changedProperties) {
        super.firstUpdated(changedProperties);
        !cachedParts && this.requestUpdate(); // polyfilled browsers require a second update
    }
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     *
     * @return TemplateResult
     */
    render() {
        const dots = [];
        for (const part of this.templateParts) {
            dots.push(html ` <i part="${part}"></i> `);
        }
        return html ` <div part="wrapper">${dots}</div> `;
    }
};
Loader = __decorate([
    customElement('ef-loader')
], Loader);
export { Loader };
