import { JSXInterface } from '../../jsx';
import { BasicElement, CSSResultGroup, PropertyValues, TemplateResult } from '@refinitiv-ui/core';
import '@refinitiv-ui/phrasebook/locale/en/notification.js';
import { Translate } from '@refinitiv-ui/translate';
import '../../icon/index.js';
/**
 * Used to show informative content when something happens in the application
 *
 * @fires collapsed - Fired when notification is collapsed.
 * @fires dismiss - Fired when the user taps close button to dismiss notification. The event is not triggered if dismiss is done programmatically.
 *
 */
export declare class Notification extends BasicElement {
    /**
     * Element version number
     * @returns version number
     */
    static get version(): string;
    /**
     * Default role of the element
     */
    protected readonly defaultRole: string | null;
    /**
     * The message to show in the notification.
     */
    message: string;
    /**
     * Notification style: Confirm
     */
    confirm: boolean;
    /**
     * Notification style: Warning
     */
    warning: boolean;
    /**
     * Notification style: Error
     */
    error: boolean;
    /**
     * Toggles the collapsed state.
     */
    collapsed: boolean;
    /**
     * Used for translations
     */
    protected t: Translate;
    /**
     * On first updated lifecycle
     * @param changedProperties changed property
     * @returns {void}
     */
    protected firstUpdated(changedProperties: PropertyValues): void;
    /**
     * Dismisses the notification, firing a `dismiss` event and collapsing the notification.
     * @returns {void}
     */
    dismiss(): void;
    /**
     * Event handler for the clear button.
     * @param event event object
     * @returns {void}
     * @private
     */
    private onClearClick;
    /**
     * Event handler for when animation end.
     * @returns {void}
     */
    private onAnimationEnd;
    /**
     * A `CSSResultGroup` that will be used
     * to style the host, slotted children
     * and the internal template of the element.
     *
     * @returns CSS template
     */
    static get styles(): CSSResultGroup;
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     *
     * @returns {TemplateResult} Render template
     */
    protected render(): TemplateResult;
}
declare global {
    interface HTMLElementTagNameMap {
        'ef-notification': Notification;
    }
}

declare global {
  interface HTMLElementTagNameMap {
    'ef-notification': Notification;
  }

  namespace JSX {
    interface IntrinsicElements {
      'ef-notification': Partial<Notification> | JSXInterface.HTMLAttributes<Notification>;
    }
  }
}

export {};
