import { __decorate } from "tslib";
import { BasicElement, css } from '@refinitiv-ui/core';
import { customElement } from '@refinitiv-ui/core/decorators/custom-element.js';
import { property } from '@refinitiv-ui/core/decorators/property.js';
import { VERSION } from '../../version.js';
/**
 * A private element to show backdrop for overlay
 */
let OverlayBackdrop = class OverlayBackdrop extends BasicElement {
    /**
     * Element version number
     * @returns version number
     */
    static get version() {
        return VERSION;
    }
    /**
     * A `CSSResultGroup` that will be used
     * to style the host, slotted children
     * and the internal template of the element.
     * @return CSS template
     */
    static get styles() {
        return css `
      :host {
        pointer-events: all;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
      }
    `;
    }
    /**
     * Set a specific z-index to override automatically calculated z-index
     * @param zIndex zIndex value
     */
    set zIndex(zIndex) {
        if (typeof zIndex === 'number') {
            this.style.setProperty('z-index', `${zIndex}`);
        }
        else {
            this.style.removeProperty('z-index');
        }
    }
};
__decorate([
    property({ type: Number, attribute: false })
], OverlayBackdrop.prototype, "zIndex", null);
OverlayBackdrop = __decorate([
    customElement('ef-overlay-backdrop')
], OverlayBackdrop);
export { OverlayBackdrop };
