import { __decorate } from "tslib";
import { BasicElement, css, html } from '@refinitiv-ui/core';
import { customElement } from '@refinitiv-ui/core/decorators/custom-element.js';
import { property } from '@refinitiv-ui/core/decorators/property.js';
import { VERSION } from '../version.js';
/**
 * A container for components.
 * It provides a standard background color and padding, depends on theme.
 */
let Panel = class Panel extends BasicElement {
    constructor() {
        super(...arguments);
        /**
         * Apply default padding from theme
         */
        this.spacing = false;
        /**
         * Set panel background to transparent
         */
        this.transparent = false;
    }
    /**
     * Element version number
     * @returns version number
     */
    static get version() {
        return VERSION;
    }
    /**
     * A `CSSResultGroup` that will be used
     * to style the host, slotted children
     * and the internal template of the element.
     * @return CSS template
     */
    static get styles() {
        return css `
      :host {
        position: relative;
        display: block;
        overflow: hidden;
        box-sizing: border-box;
      }

      :host([transparent]) {
        background: transparent;
        border: 0;
      }

      :host([spacing]) {
        padding: 10px; /* default padding - can be overridden by theme */
      }
    `;
    }
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     * @return Render template
     */
    render() {
        return html `<slot></slot>`;
    }
};
__decorate([
    property({ type: Boolean, reflect: true })
], Panel.prototype, "spacing", void 0);
__decorate([
    property({ type: Boolean, reflect: true })
], Panel.prototype, "transparent", void 0);
Panel = __decorate([
    customElement('ef-panel')
], Panel);
export { Panel };
