import { __decorate } from "tslib";
import { BasicElement, css, html } from '@refinitiv-ui/core';
import { customElement } from '@refinitiv-ui/core/decorators/custom-element.js';
import { property } from '@refinitiv-ui/core/decorators/property.js';
import { VERSION } from '../../version.js';
let SliderMarker = class SliderMarker extends BasicElement {
    constructor() {
        super(...arguments);
        /**
         * Used to determine the position of the marker on the scale.
         */
        this.value = '';
        /**
         * Specify label alignment
         */
        this.labelAlign = null;
    }
    /**
     * Element version number
     * @returns version number
     */
    static get version() {
        return VERSION;
    }
    static get styles() {
        return css `
      :host {
        position: absolute;
      }
      [part='marker'] {
        width: 100%;
        height: 100%;
      }
      [part='label'] {
        white-space: nowrap;
        position: absolute;
      }
    `;
    }
    /**
     * On first updated lifecycle
     * @param changedProperties changed properties
     * @returns {void}
     */
    firstUpdated(changedProperties) {
        super.firstUpdated(changedProperties);
        this.setAttribute('aria-hidden', 'true');
    }
    /**
     * A `TemplateResult` that will be used
     * to render the updated internal template.
     * @returns Render template
     */
    render() {
        return html `
      <div part="marker"></div>
      <div part="label">
        <slot></slot>
      </div>
    `;
    }
};
__decorate([
    property({ type: String })
], SliderMarker.prototype, "value", void 0);
__decorate([
    property({ type: String, reflect: true, attribute: 'label-align' })
], SliderMarker.prototype, "labelAlign", void 0);
SliderMarker = __decorate([
    customElement('ef-slider-marker')
], SliderMarker);
export { SliderMarker };
