import escapeStringRegexp from 'escape-string-regexp';
/**
 * Default filter used by tree
 * @param el Tree instance to filter
 * @returns Filter accepting an item
 */
export const createDefaultFilter = (el) => {
    // reference query string for validating queryRegExp cache state
    let query = '';
    // cache RegExp
    let queryRegExp;
    // Get current RegExp, or renew if out of date
    // this is fetched on demand by filter/renderer
    // only created once per query
    const getRegularExpressionOfQuery = () => {
        if (el.query !== query || !queryRegExp) {
            query = el.query || '';
            queryRegExp = new RegExp(escapeStringRegexp(query), 'i');
        }
        return queryRegExp;
    };
    // return scoped custom filter
    return (item, manager) => {
        const label = manager.composer.getItemPropertyValue(item, 'label');
        if (!label) {
            return false;
        }
        const regex = getRegularExpressionOfQuery();
        const result = regex.test(label);
        return result;
    };
};
